@@ -1,6 +1,6 @@
 package HTML::FormWidgets;
 
-# @(#)$Id: FormWidgets.pm 63 2008-06-29 09:35:07Z pjf $
+# @(#)$Id: FormWidgets.pm 67 2008-07-22 22:42:48Z pjf $
 
 use strict;
 use warnings;
@@ -9,8 +9,9 @@ use English qw(-no_match_vars);
 use File::Spec::Functions;
 use HTML::Accessors;
 use Readonly;
+use Text::Markdown qw(markdown);
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 63 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 67 $ =~ /\d+/gmx );
 
 Readonly my $NUL   => q();
 Readonly my $TTS   => q( ~ );
@@ -51,7 +52,8 @@ Readonly my %ATTRS =>
      style        => $NUL,          subtype      => undef,
      swidth       => 1000,          tabstop      => 3,
      target       => $NUL,          templatedir  => undef,
-     text         => $NUL,          tip          => $NUL,
+     text         => $NUL,
+     text_obj     => undef,         tip          => $NUL,
      tiptype      => q(dagger),     title        => $NUL,
      type         => undef,         url          => undef,
      value        => 1,             values       => [],
@@ -103,7 +105,7 @@ sub build {
 sub new {
    my ($me, @rest) = @_;
    my $args        = $me->_arg_list( @rest );
-   my ($class, $method, $msg_id, $ref, $self, $text, @tmp, $val);
+   my ($class, $method, $msg_id, $ref, $self, $suffix, $text, @tmp, $val);
 
    # Start with some hard coded defaults;
    $self = { %ATTRS };
@@ -112,6 +114,9 @@ sub new {
    $ref = { content_type => $args->{content_type} } if ($args->{content_type});
    $self->{elem} = HTML::Accessors->new( $ref );
 
+   $suffix = $args->{content_type} && $args->{content_type} eq q(text/html)
+           ? q(>) : q( />);
+
    # Bare minimum is fields + id to get a useful widget
    for (qw(ajaxid fields id name)) {
       $self->{ $_ } = $args->{ $_ } if (exists $args->{ $_ });
@@ -170,6 +175,10 @@ sub new {
 
    $self->{nodeId} = q(node_0); # Define accessor by hand to auto increment
 
+   $self->text_obj( Text::Markdown->new
+                    ( empty_element_suffix => $suffix,
+                      tab_width            => $self->tabstop ) );
+
    # Pander to lazy filling out of static definitions
    $self->container( $self->type =~ m{ chooser|file|label|note }mx ? 0 : 1 )
       unless (defined $self->container);
@@ -219,13 +228,28 @@ sub new {
 # Object methods
 
 sub msg {
-   my ($me, $key) = @_;
+   # Return the language dependant text of the requested message
+   my ($me, $name, $args) = @_; my ($key, $msgs, $pat, $text, $val);
 
-   return q() unless ($me->messages);
+   return q() unless ($name && ($msgs = $me->messages));
 
-   my $msg = $me->messages->{ $key || q() } || {};
+   if (exists $msgs->{ $name } && ($text = $msgs->{ $name }->{text})) {
+      if ($msgs->{ $name }->{markdown}) {
+         $text = $me->text_obj->markdown( $text );
+      }
 
-   return $msg->{text} || q();
+      if ($args) {
+         # Inflate arg values enclosed in [%%]
+         for $key (keys %{ $args }) {
+            $pat  = q(\[% \s+ ).$key.q( \s+ %\]);
+            $val  = $args->{ $key } || q();
+            $text =~ s{ $pat }{$val}gmx;
+         }
+      }
+   }
+   else { $text = q() }
+
+   return $text;
 }
 
 sub render {
@@ -342,7 +366,7 @@ HTML::FormWidgets - Create HTML form markup
 
 =head1 Version
 
-0.1.$Rev: 63 $
+0.1.$Rev: 67 $
 
 =head1 Synopsis
 
@@ -745,6 +769,8 @@ None
 
 =item L<Syntax::Highlight::Perl>
 
+=item L<Text::Markdown>
+
 =item L<Text::ParseWords>
 
 =item L<Text::Tabs>
